function []=startzei(fktname,x0,gradname,hessename,iterationmax);
% ======================================================================
% Startroutine fuer das Trust-Region Verfahren
% mit Zeichnen des Vertrauensbereichs.
%
% Erstellt fuer die Veranstaltung
% Weiterbildenes Studium fuer Ingenieure WS 98/99
%
% Helge Baumann, 09.10.1998
% Aenderungen S.F.
% ----------------------------------------------------------------------
% Aurufparameter:
%  
% fktname : Name der Funktion F, deren Minimum bestimmt 
%   werden soll. An <fktname> wird ein Spaltenwektor(!) uebergeben. 
%   F ist eine Funktion von R^n -> R. Standard : 'testfunktion'
% x0 : Spaltenvektor der Dimension n. Standard: [-2; 2]
% gradname : Name der Gradientenfunktion zu fktname.
% hessename : Name der Funktion, die die Hessematrix zu fktname liefert.
% iterationmax : Anzahl der maximalen Iterationen. Standard: 5

global xmin
global xmax

% Anzahl der Funktionsauswertungen
global nfc 
nfc = 0;
global ngc
ngc = 0;
global nGc
nGc = 0;


% Anzahl der maximalen Iterationen
if nargin < 5, iterationmax = 5; end

% Name der Hessematrix zu fktname
if nargin < 4, hessename = 'hrosenbrock'; end;

% Name der Gradientenfunktion zu fktname
if nargin < 3, gradname = 'grosenbrock'; end;

% Startvektor
if nargin < 2, x0 = [-2; 2]; end
[n,m] = size(x0); % n = Dimension des Startvektors

% Name der zu minimierenden Funktion
if nargin < 1, fktname = 'rosenbrock'; end

% Name der Ausgaberoutine
outputname = '';

if n>2 
	error('nur fuer n=2');
end;

[lsg,wert,iterationen,nfc,ngc,nhc] = ...
   trustzei(fktname,x0,gradname,hessename,iterationmax,outputname);
return;
break
























